@@ -5,37 +5,38 @@
 
 Cp_s_var <- function(T=298.15, P=1, omega.PrTr=0, Z=0) {
   # solvation contribution to heat capacity in the HKF EOS, divided by omega(Pr,Tr) (calories)
-  Cp_s <- hkf("Cp", T=T, P=P, eos=data.frame(omega=omega.PrTr, Z=Z), contrib="s")
+  Cp_s <- hkf("Cp", parameters=data.frame(omega=omega.PrTr, Z=Z), T=T, P=P, contrib="s")$aq
   return(Cp_s[[1]][, 1]/omega.PrTr)
 }
 
 V_s_var <- function(T=298.15, P=1, omega.PrTr=0, Z=0) {
   # solvation contribution to volume in the HKF EOS, divided by omega(Pr,Tr) (cm3.bar)
   # [the negative sign on this term as written in the HKF EOS is accounted for by hkf()]
-  V_s <- hkf("V", T=T, P=P, eos=data.frame(omega=omega.PrTr, Z=Z), contrib="s")
+  V_s <- hkf("V", parameters=data.frame(omega=omega.PrTr, Z=Z), T=T, P=P, contrib="s")$aq
   return(V_s[[1]][, 1]/convert(omega.PrTr, "cm3bar"))
 }
 
 EOSvar <- function(var, T, P, ...) {
   # get the variables of a term in a regression equation
   # T (K), P (bar)
-  opt <- get("thermo")$opt
+  Theta <- 228 # K
+  Psi <- 2600  # bar
   out <- switch(EXPR = var,
     "(Intercept)" = rep(1, length(T)),
     "T" = T,
     "P" = P,
-    "TTheta" = T-opt$Theta,                 # T-Theta
-    "invTTheta" = (T-opt$Theta)^-1,         # 1/(T-Theta)
-    "TTheta2" = (T-opt$Theta)^2,            # (T-Theta)^2
-    "invTTheta2" = (T-opt$Theta)^-2,        # 1/(T-Theta)^2
-    "invPPsi" = (P+opt$Psi)^-1,             # 1/(P-Psi)
-    "invPPsiTTheta" = (P+opt$Psi)^-1 * (T-opt$Theta)^-1,  # 1/[(P-Psi)(T-Theta)]
+    "TTheta" = T - Theta,                 # T-Theta
+    "invTTheta" = (T - Theta)^-1,         # 1/(T-Theta)
+    "TTheta2" = (T - Theta)^2,            # (T-Theta)^2
+    "invTTheta2" = (T - Theta)^-2,        # 1/(T-Theta)^2
+    "invPPsi" = (P + Psi)^-1,             # 1/(P+Psi)
+    "invPPsiTTheta" = (P + Psi)^-1 * (T - Theta)^-1,  # 1/[(P+Psi)(T-Theta)]
     "TXBorn" = T*water("XBorn", T=T, P=P)[, 1],
     "drho.dT" = -water("rho", T=T, P=P)[, 1]*water("E", T=T, P=P)[, 1],
     "V.kT" = water("V", T=T, P=P)[, 1]*water("kT", T=T, P=P)[, 1],
     # fallback: get a variable that is a property of water, or
     # is any other function by name (possibly a user-defined function)
-    (  if(var %in% water.props()) water(var, T, P)[, 1]
+    (  if(var %in% water.SUPCRT92()) water(var, T, P)[, 1]
        else if(exists(var)) {
          if(is.function(get(var))) {
            if(all(c("T", "P") %in% names(formals(get(var))))) get(var)(T=T, P=P, ...)
@@ -72,7 +73,7 @@ EOSlab <- function(var, coeff="") {
     "kT" = substitute(YYY%*%kappa[italic(T)], list(YYY=coeff)),
     "alpha" = substitute(YYY%*%alpha, list(YYY=coeff)),
     "beta" = substitute(YYY%*%beta, list(YYY=coeff)),
-    "diel" = substitute(YYY%*%epsilon, list(YYY=coeff)),
+    "epsilon" = substitute(YYY%*%epsilon, list(YYY=coeff)),
     "rho" = substitute(YYY%*%rho, list(YYY=coeff)),
     "NBorn" = substitute(YYY%*%italic(N), list(YYY=coeff)),
     "QBorn" = substitute(YYY%*%italic(Q), list(YYY=coeff)),
