@@ -1,25 +1,25 @@
 # CHNOSZ/protein.info.R
 
 # calculate formulas and summarize properties of proteins
-# pinfo: find rownumber in thermo$protein
+# pinfo: find rownumber in thermo()$protein
 # protein.length: lengths of the indicated proteins
 # protein.formula: chemical makeup of the indicated proteins
-# protein.obigt: perform group additivity calculations
+# protein.OBIGT: perform group additivity calculations
 # protein.basis: coefficients of basis species in formation reactions of [ionized] proteins [residues]
 # protein.equil: step-by-step example of protein equilibrium calculation
 
 pinfo <- function(protein, organism=NULL, residue=FALSE, regexp=FALSE) {
   # return the `protein` (possibly per residue) for:
   #   dataframe `protein`
-  # return the rownumber(s) of thermo$protein for:
+  # return the rownumber(s) of thermo()$protein for:
   #   character `protein`, e.g. LYSC_CHICK
   #   character `protein` and `organism`, e.g. 'LYSC', 'CHICK'
-  # return the row(s) of thermo$protein (possibly per residue) for:
+  # return the row(s) of thermo()$protein (possibly per residue) for:
   #   numeric `protein` (the rownumber itself)
   if(is.data.frame(protein)) out <- protein
   if(is.numeric(protein)) {
     t_p <- get("thermo", CHNOSZ)$protein
-    # drop NA matches to thermo$protein
+    # drop NA matches to thermo()$protein
     iproteins <- 1:nrow(t_p)
     protein[!protein %in% iproteins] <- NA
     # get amino acid counts
@@ -37,7 +37,7 @@ pinfo <- function(protein, organism=NULL, residue=FALSE, regexp=FALSE) {
       if(!is.null(organism)) iorganism <- grepl(organism, t_p$organism)
       iprotein <- which(iprotein & iorganism)
     } else {
-      # search for protein or protein_organism in thermo$protein
+      # search for protein or protein_organism in thermo()$protein
       t_p_names <- paste(t_p$protein, t_p$organism, sep="_")
       if(is.null(organism)) my_names <- protein
       else my_names <- paste(protein, organism, sep="_")
@@ -66,7 +66,7 @@ protein.length <- function(protein, organism=NULL) {
   return(pl)
 }
 
-protein.obigt <- function(protein, organism=NULL, state=thermo()$opt$state) {
+protein.OBIGT <- function(protein, organism=NULL, state=thermo()$opt$state) {
   # display and return the properties of
   # proteins calculated from amino acid composition
   aa <- pinfo(pinfo(protein, organism))
@@ -77,13 +77,13 @@ protein.obigt <- function(protein, organism=NULL, state=thermo()$opt$state) {
   groups <- c("AABB", colnames(aa)[6:25], bbgroup)
   # put brackets around the group names
   groups <- paste("[", groups, "]", sep="")
-  # the rownumbers of the groups in thermo$obigt
+  # the rownumbers of the groups in thermo()$OBIGT
   groups_state <- paste(groups, state)
-  obigt <- get("thermo", CHNOSZ)$obigt
-  obigt_state <- paste(obigt$name, obigt$state)
-  igroup <- match(groups_state, obigt_state)
-  # the properties are in columns 9-21 of thermo$obigt
-  groupprops <- obigt[igroup, 9:21]
+  OBIGT <- get("thermo", CHNOSZ)$OBIGT
+  OBIGT_state <- paste(OBIGT$name, OBIGT$state)
+  igroup <- match(groups_state, OBIGT_state)
+  # the properties are in columns 9-21 of thermo()$OBIGT
+  groupprops <- OBIGT[igroup, 9:21]
   # the elements in each of the groups
   groupelements <- i2A(igroup)
   # a function to work on a single row of aa
@@ -106,7 +106,7 @@ protein.obigt <- function(protein, organism=NULL, state=thermo()$opt$state) {
     # now the species name
     name <- paste(aa$protein, aa$organism, sep="_")
     # make some noise for the user
-    message("protein.obigt: found ", appendLF=FALSE)
+    message("protein.OBIGT: found ", appendLF=FALSE)
     message(name, " (", f, ", ", appendLF=FALSE)
     message(round(length, 3), " residues)")
     ref <- aa$ref
@@ -163,7 +163,7 @@ protein.equil <- function(protein, T=25, loga.protein=0, digits=4) {
   # get some general information about the proteins
   pname <- paste(aa$protein, aa$organism, sep="_")
   plength <- protein.length(aa)
-  # use thermo$basis to decide whether to ionize the proteins
+  # use thermo()$basis to decide whether to ionize the proteins
   thermo <- get("thermo", CHNOSZ)
   ionize.it <- FALSE
   iword <- "nonionized"
@@ -174,7 +174,7 @@ protein.equil <- function(protein, T=25, loga.protein=0, digits=4) {
     pH <- -thermo$basis$logact[match("H+", rownames(bmat))]
     mymessage("protein.equil: pH from thermo$basis is ", pH)
   }
-  # tell the user whose [Met] is in thermo$obigt
+  # tell the user whose [Met] is in thermo$OBIGT
   info.Met <- info(info('[Met]', "aq"))
   mymessage("protein.equil: [Met] is from reference ", info.Met$ref1)
   ## first set of output: show results of calculations for a single protein
